<?php

namespace App\Http\Controllers;

use App\Models\Certificado;
use App\Models\Charla;
use App\Models\User;
use Illuminate\Http\Request;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\DB;


/**
 * Class CertificadoController
 * @package App\Http\Controllers
 */
class CertificadoController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $certificados = Certificado::paginate();

        return view('certificado.index', compact('certificados'))
            ->with('i', (request()->input('page', 1) - 1) * $certificados->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $certificado = new Certificado();

        $charlas = Charla::pluck('tema', 'id');
        $usuarios = User::select(DB::raw("CONCAT(name, ' ', apellido) as full_name"), 'id')
        ->pluck('full_name', 'id');
        return view('certificado.create', compact('certificado', 'usuarios', 'charlas'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate(Certificado::$rules);

        $certificado = Certificado::create($request->all());

        return redirect()->route('certificados.index')
            ->with('success', 'Certificado created successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $certificado = Certificado::find($id);

        return view('certificado.show', compact('certificado'));
    }

    public function pdf($id)
    {
        $certificado = Certificado::find($id);
        //return response()->json($certificado);
        $pdf = Pdf::loadView('certificado.pdf', ['certificado' => $certificado]);
        
        $pdf->setPaper('landscape');
     
        return $pdf->stream('certificacion.pdf');
    }

    public function certificadosepdf($id){
        //return response()->json($id);
        $datos=DB::table('inscribe_usuario_eventos')
                ->join('users','users.id','=','inscribe_usuario_eventos.usuario_id')
                ->where('inscribe_usuario_eventos.id',$id)->get();
               
        $evento=DB::table('inscribe_usuario_eventos')
                ->join('eventos','eventos.id','=','inscribe_usuario_eventos.evento_id')
                ->where('inscribe_usuario_eventos.id',$id)->get();
        $charla=DB::table('charlas')->where('charlas.evento_id',$evento[0]->evento_id)->get();
        //return response()->json($charla);
        $certificado=DB::table('certificados')->where('certificados.charla_id',$charla[0]->id)->get();
        $docente=DB::table('users')->where('users.id',$certificado[0]->usuario_id)->get();
        $pdf = Pdf::loadView('certificado.estudiantepdf', compact('datos','evento','charla','certificado','docente'));
        $pdf->setPaper('letter','portrait');
        return $pdf->stream('certificacion.pdf');
       
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $certificado = Certificado::find($id);

        $charlas = Charla::pluck('tema', 'id');
        $usuarios = User::pluck('name', 'id');

        return view('certificado.edit', compact('certificado', 'usuarios', 'charlas'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Certificado $certificado
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Certificado $certificado)
    {
        request()->validate(Certificado::$rules);

        $certificado->update($request->all());

        return redirect()->route('certificados.index')
            ->with('success', 'Certificado updated successfully');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $certificado = Certificado::find($id)->delete();

        return redirect()->route('certificados.index')
            ->with('success', 'Certificado deleted successfully');
    }

    public function encontrarcertificado(Request $request)
    {
        // Obtener el nombre buscado desde el formulario
        $codigo = $request->input('busqueda');
        //return response()->json($nombre);
        // Buscar estudiantes cuyo nombre coincida
        $resultados = DB::table('inscribe_usuario_eventos')
        ->join('users', 'users.id', '=', 'inscribe_usuario_eventos.usuario_id')
        ->join('eventos', 'eventos.id', '=', 'inscribe_usuario_eventos.evento_id')
        ->select('users.name', 'users.apellido', 'users.documento', 
                 'inscribe_usuario_eventos.codigo', 'eventos.fecha', 
                 'eventos.tipo_evento','inscribe_usuario_eventos.id as idparticipante','eventos.nombre_evento')
        ->where('inscribe_usuario_eventos.codigo', 'LIKE', $codigo)
        ->get();
    
        // Verificar si se encontraron estudiantes
        if ($resultados->isNotEmpty()) {
            //return response()->json($resultados);
            return view('certificado.resultados', compact('resultados'));
        }
        return view('certificado.resultados')->with('mensaje', 'No se encontraron certificados.');
    }
}
