<?php

namespace App\Http\Controllers;

use App\Models\Materiale;
use App\Models\Ambiente;
use App\Models\Evento;
use App\Models\Charla;
use App\Models\InscribeUsuarioEvento;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

/**
 * Class EventoController
 * @package App\Http\Controllers
 */
class EventoController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $eventos = Evento::paginate();

        $inscritos = InscribeUsuarioEvento::all();
        $sw = 'false';

        return view('evento.index', compact('eventos', 'inscritos', 'sw'))
            ->with('i', (request()->input('page', 1) - 1) * $eventos->perPage());
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $evento = new Evento();
        return view('evento.create', compact('evento'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //return response()->json($request);
        $newpost = new Evento();

        if ($request->hasFile('portada')) {
            $file = $request->file('portada');
            $destinoPath = 'portadas/';
            $filename = time() . '-' . $file->getClientOriginalName();
            $uploadSucess = $request->file('portada')->move($destinoPath, $filename);
            $newpost->portada = $destinoPath . $filename;
        }

        $newpost->nombre_evento = $request->nombre_evento;
        $newpost->descripcion = $request->descripcion;
        $newpost->tipo_evento = $request->tipo_evento;
        $newpost->nro_cupos = $request->nro_cupos;
        $newpost->fecha = $request->fecha;
        $newpost->prefijo = $request->prefijo;

        $newpost->save();

        // request()->validate(Evento::$rules);

        // $evento = Evento::create($request->all());

        return redirect()->route('eventos.index')
            ->with('success', 'Evento created successfully.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        
        $evento = Evento::find($id);
        $charlas = Charla::all();
        $materiales = Materiale::all();
        $ambientes = Ambiente::all();
        $inscritos = InscribeUsuarioEvento::all();
        $sw = 'false';

        $c = 0;
        foreach ($inscritos as $inscrito) {
            if ($inscrito->evento_id == $id) {
                $c+=1;
            }
        }
        //return response()->json($inscritos);
        return view('evento.show', compact('evento', 'charlas', 'materiales', 'ambientes', 'inscritos', 'sw', 'c'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $evento = Evento::find($id);

        return view('evento.edit', compact('evento'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  Evento $evento
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Evento $evento)
    {
        $newpost = $evento;

        if ($request->hasFile('portada')) {
            $file = $request->file('portada');
            $destinoPath = 'portadas/';
            $filename = time() . '-' . $file->getClientOriginalName();
            $uploadSucess = $request->file('portada')->move($destinoPath, $filename);
            $newpost->portada = $destinoPath . $filename;
        }

        $newpost->nombre_evento = $request->nombre_evento;
        $newpost->descripcion = $request->descripcion;
        $newpost->tipo_evento = $request->tipo_evento;
        $newpost->nro_cupos = $request->nro_cupos;
        $newpost->fecha = $request->fecha;

        $newpost->save();
        // request()->validate(Evento::$rules);

        // $evento->update($request->all());

        return redirect()->route('eventos.index')
            ->with('success', 'Evento updated successfully');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\RedirectResponse
     * @throws \Exception
     */
    public function destroy($id)
    {
        $evento = Evento::find($id)->delete();

        return redirect()->route('eventos.index')
            ->with('success', 'Evento deleted successfully');
    }
    public function listaEstudiantes($id){
        
        $datos=DB::table('inscribe_usuario_eventos')
        ->join('users','users.id','=','inscribe_usuario_eventos.usuario_id')
        ->where('inscribe_usuario_eventos.evento_id','=',$id)->select('inscribe_usuario_eventos.usuario_id','users.name','users.email','inscribe_usuario_eventos.estado_asistencia','inscribe_usuario_eventos.asistencia','inscribe_usuario_eventos.id as idparticipante')->get();
        
        return view('evento.listaestudiante',compact('datos'));
    }
    public function verificarestado($id){
        $datos=DB::table('inscribe_usuario_eventos')
        ->join('users','users.id','=','inscribe_usuario_eventos.usuario_id')
        ->join('eventos','eventos.id','=','inscribe_usuario_eventos.evento_id')
        ->where('inscribe_usuario_eventos.usuario_id',$id)->get();
        return view('inscribe-usuario-evento.verificarestado',compact('datos'));
        return response()->json($datos);
    }
    public function pagarevento($id, $idEstudiante){
        $datosEvento=DB::table('eventos')->where('eventos.id',$id)->get();
        $datosEstudiante=DB::table('inscribe_usuario_eventos')
        ->join('users','users.id','=','inscribe_usuario_eventos.usuario_id')
        ->where('inscribe_usuario_eventos.usuario_id',$idEstudiante)->get();
        //return response()->json($datosEstudiante);
        return view('inscribe-usuario-evento.pagar',compact('datosEvento','datosEstudiante'));
    }
    public function registrarpago(Request $request, $id){
        
        if ($request->hasFile('boleta')) {
            $file = $request->file('boleta');
            $destinoPath = 'boletas/';
            $filename = time() . '-' . $file->getClientOriginalName();
            $uploadSucess = $request->file('boleta')->move($destinoPath, $filename);
            $imagenpago = $destinoPath . $filename;
        }
        InscribeUsuarioEvento::where('usuario_id',$id)->update(['boleta'=>$imagenpago]);
        return redirect()->route('eventos.index')
        ->with('success', 'Se envio la boleta de pago correctamente');
    }
    public function validarpago(Request $request, $id){
        $valor=$request->validar;
        if($valor==="on"){
            InscribeUsuarioEvento::where('usuario_id',$id)->update(['estado_asistencia'=>'aceptado']);
            return redirect()->back()->with('success', 'Se acepto la boleta de pago correctamente');
        }
        else{
            InscribeUsuarioEvento::where('usuario_id',$id)->update(['estado_asistencia'=>'pendiente']);
            return redirect()->back()->with('danger', 'No Se acepto la boleta de pago correctamente');
        }
    }
    public function listaestudiantehabilitados($id){
        $datos=DB::table('inscribe_usuario_eventos')
        ->join('users','users.id','=','inscribe_usuario_eventos.usuario_id')
        ->where('inscribe_usuario_eventos.evento_id','=',$id)
        ->where('inscribe_usuario_eventos.estado_asistencia','=','aceptado')
        ->select('inscribe_usuario_eventos.usuario_id','users.name','users.apellido','users.documento','users.email','inscribe_usuario_eventos.estado_asistencia','inscribe_usuario_eventos.codigo','inscribe_usuario_eventos.asistencia','inscribe_usuario_eventos.id as idinscrito')->get();
        return view('evento.estudiantehabilitado',compact('datos','id'));
        
    }

    public function actualizarasistencia(Request $request)
    {
        return redirect()->back()->with('success', 'Se actualizó la lista de asistencia');
    }
    public function actualizarAsistenciaIndividual(Request $request)
    {
        // Obtener el prefijo del evento
        $prefijo = DB::table('eventos')->where('id', $request->evento_id)->select('prefijo')->first();
        
        // Contar solo aquellos con asistencia = 1
        $total = InscribeUsuarioEvento::where('asistencia', 1)
            ->where('evento_id', $request->evento_id)
            ->count();
        
        // Verifica si se está activando o desactivando la asistencia
        if ($request->asistencia == 1) {
            $codigo = $this->generarCodigoUnico($prefijo->prefijo, $request->evento_id);
            InscribeUsuarioEvento::where('id', $request->id)->update(['asistencia' => 1, 'codigo' => $codigo]);
        } else {
            // Si la asistencia es 0, borra el código y pone asistencia en 0
            InscribeUsuarioEvento::where('id', $request->id)->update(['asistencia' => 0, 'codigo' => null]);
        }
    
        return response()->json(['success' => true]);
    }

    public function generarCodigoUnico($prefijo, $evento_id)
    {
        $codigoGenerado = null;
        $contador = 1;

        do {
            $codigoGenerado = $prefijo . "-" . str_pad($contador, 4, '0', STR_PAD_LEFT);
            $contador++;
        } while (InscribeUsuarioEvento::where('codigo', $codigoGenerado)->where('evento_id', $evento_id)->exists());

        return $codigoGenerado;
    }
}

